"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var process_container_component_1 = require("./process-container.component");
var process_event_class_1 = require("./process-event.class");
var Rx_1 = require("rxjs/Rx");
var process_options_class_1 = require("./process-options.class");
var ProcessService = (function () {
    function ProcessService(componentFactoryResolver, appRef, options) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.appRef = appRef;
        this.eventSource = new Rx_1.Subject();
        this.events = this.eventSource.asObservable();
        this.speed = 200;
        this.options = new process_options_class_1.ProcessOptions();
        this.visible = false;
        this.progress = 0;
        if (options) {
            Object.assign(this.options, options);
        }
    }
    Object.defineProperty(ProcessService.prototype, "Visible", {
        get: function () {
            return this.visible;
        },
        set: function (value) {
            if (value !== undefined && value !== null) {
                this.visible = value;
                this.emitEvent(new process_event_class_1.ProcessEvent(process_event_class_1.ProcessEventType.VISIBLE, this.visible));
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ProcessService.prototype, "Progress", {
        get: function () {
            return this.progress;
        },
        set: function (value) {
            if (value !== undefined && value !== null) {
                this.progress = value;
                this.emitEvent(new process_event_class_1.ProcessEvent(process_event_class_1.ProcessEventType.PROGRESS, this.progress));
            }
        },
        enumerable: true,
        configurable: true
    });
    ProcessService.prototype.setRootViewContainerRef = function (vRef) {
        this.rootViewContainerRef = vRef;
    };
    ProcessService.prototype.start = function () {
        this.set();
        this.clear();
        this.Visible = true;
        if (this.options.type === 'bar') {
            this.startBarProcess();
        }
    };
    ProcessService.prototype.done = function () {
        this.clear();
        if (this.options.type === 'bar') {
            this.doneBarProcess();
        }
        else if (this.options.type === 'page') {
            this.donePageProcess();
        }
    };
    ProcessService.prototype.startBarProcess = function () {
        var _this = this;
        this.Progress = 0;
        this.intervalId = setInterval(function () {
            _this.trickle();
            if (_this.Progress === 100) {
                _this.done();
            }
        }, this.speed);
    };
    ProcessService.prototype.doneBarProcess = function () {
        var _this = this;
        this.Progress = 100;
        this.visibleTimeoutId = setTimeout(function () {
            _this.Visible = false;
            _this.disposeTimeoutId = setTimeout(function () {
                _this.Progress = 0;
                _this.dispose();
            }, 600);
        }, 250);
    };
    ProcessService.prototype.donePageProcess = function () {
        var _this = this;
        this.visibleTimeoutId = setTimeout(function () {
            _this.Visible = false;
            _this.disposeTimeoutId = setTimeout(function () {
                _this.dispose();
            }, 700);
        }, 2000);
    };
    ProcessService.prototype.trickle = function (amount) {
        if (this.progress > 1) {
            return;
        }
        if (amount === undefined || amount === null) {
            if (this.progress >= 0 && this.progress < 0.2) {
                amount = 0.1;
            }
            else if (this.progress >= 0.2 && this.progress < 0.5) {
                amount = 0.04;
            }
            else if (this.progress >= 0.5 && this.progress < 0.8) {
                amount = 0.02;
            }
            else if (this.progress >= 0.8 && this.progress < 0.99) {
                amount = 0.005;
            }
            else {
                amount = 0;
            }
        }
        this.Progress = this.clamp(this.Progress + amount, 0, 0.994);
    };
    ProcessService.prototype.clear = function () {
        if (this.intervalId) {
            clearInterval(this.intervalId);
            this.intervalId = null;
        }
        if (this.visibleTimeoutId) {
            clearTimeout(this.visibleTimeoutId);
            this.visibleTimeoutId = null;
        }
        if (this.disposeTimeoutId) {
            clearTimeout(this.disposeTimeoutId);
            this.disposeTimeoutId = null;
        }
    };
    ProcessService.prototype.dispose = function () {
        if (this.container) {
            this.container.destroy();
            this.container = null;
            return;
        }
        return;
    };
    ProcessService.prototype.set = function () {
        if (!this.container) {
            if (!this.rootViewContainerRef) {
                try {
                    this.rootViewContainerRef =
                        this.appRef['_rootComponents'][0]['_hostElement'].vcRef;
                }
                catch (e) {
                    console.log(new Error('Please set root ViewContainerRef using ' +
                        'setRootViewContainerRef(vRef: ViewContainerRef) method.'));
                }
            }
            var providers = core_1.ReflectiveInjector.resolve([
                { provide: process_options_class_1.ProcessOptions, useValue: this.options }
            ]);
            var processBarFactory = this.componentFactoryResolver.resolveComponentFactory(process_container_component_1.ProcessContainerComponent);
            var childInjector = core_1.ReflectiveInjector.fromResolvedProviders(providers, this.rootViewContainerRef.parentInjector);
            this.container =
                this.rootViewContainerRef.createComponent(processBarFactory, this.rootViewContainerRef.length, childInjector);
        }
    };
    ProcessService.prototype.emitEvent = function (event) {
        if (this.eventSource) {
            this.eventSource.next(event);
        }
    };
    ProcessService.prototype.clamp = function (n, min, max) {
        if (n < min) {
            return min;
        }
        if (n > max) {
            return max;
        }
        return n;
    };
    return ProcessService;
}());
ProcessService.decorators = [
    { type: core_1.Injectable },
];
ProcessService.ctorParameters = function () { return [
    { type: core_1.ComponentFactoryResolver, },
    { type: core_1.ApplicationRef, },
    { type: process_options_class_1.ProcessOptions, decorators: [{ type: core_1.Optional },] },
]; };
exports.ProcessService = ProcessService;
//# sourceMappingURL=process.service.js.map