/**
 * process-bar.component
 */

import { Component, OnDestroy, OnInit } from '@angular/core';
import { ProcessService } from './process.service';
import { Subscription } from 'rxjs/Rx';
import { ProcessEvent, ProcessEventType } from './process-event.class';
import { ProcessOptions } from './process-options.class';

@Component({
    selector: 'app-process-bar',
    template: `<div class="yk-loading-bar-process" [ngStyle]="getProcessBarStyles()"></div>`,
    styles: [`*,::after,::before{-moz-box-sizing:border-box;box-sizing:border-box}.yk-loading-bar-process{background-color:#b22222;color:#b22222;height:2px;-moz-box-shadow:0 0 10px 0;box-shadow:0 0 10px 0;-webkit-transition:all .2s ease-in-out,opacity .5s ease;-moz-transition:all .2s ease-in-out,opacity .5s ease;transition:all .2s ease-in-out,opacity .5s ease;opacity:0}.yk-loading-bar-spinner{display:block;position:fixed;top:12px;right:12px}`],
})
export class ProcessBarComponent implements OnInit, OnDestroy {

    private progress: number = 0;
    private visible: boolean = true;
    private sub: Subscription;

    constructor( private service: ProcessService,
                 private options: ProcessOptions ) {
    }

    public ngOnInit() {
        this.sub = this.service.events.subscribe(
            ( event: ProcessEvent ) => {
                if (event.type === ProcessEventType.VISIBLE) {
                    this.visible = event.value;
                } else if (event.type === ProcessEventType.PROGRESS) {
                    this.progress = event.value * 100;
                }
            }
        );
    }

    public ngOnDestroy(): void {
        if (this.sub) {
            this.sub.unsubscribe();
        }
    }

    public getProcessBarStyles(): any {
        return {
            'width': this.progress + '%',
            'height.px': this.options.height,
            'opacity': this.visible ? 1 : 0,
            'background-color': this.options.color,
            'color': this.options.color
        };
    }
}
