/**
 * process-icon.component
 */

import { Component, OnDestroy, OnInit } from '@angular/core';
import { Subscription } from 'rxjs/Rx';
import { ProcessEvent, ProcessEventType } from './process-event.class';
import { ProcessService } from './process.service';
import { ProcessOptions } from './process-options.class';

@Component({
    selector: 'app-process-icon',
    template: `<div class="yk-loading-bar-spinner-icon" [ngStyle]="getProcessIconStyles()"></div>`,
    styles: [`*,::after,::before{-moz-box-sizing:border-box;box-sizing:border-box}.yk-loading-bar-spinner-icon{position:fixed;top:15px;right:15px;width:18px;height:18px;-moz-box-sizing:border-box;box-sizing:border-box;border:solid 2px transparent;border-top-color:#b22222;border-left-color:#b22222;-moz-border-radius:50%;border-radius:50%;opacity:0;-webkit-transition:opacity .5s ease-in-out;-moz-transition:opacity .5s ease-in-out;transition:opacity .5s ease-in-out;-webkit-animation:yk-spinning .4s linear infinite;-moz-animation:yk-spinning .4s linear infinite;animation:yk-spinning .4s linear infinite}@-webkit-keyframes yk-spinning{0%{-webkit-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@-moz-keyframes yk-spinning{0%{-moz-transform:rotate(0);transform:rotate(0)}100%{-moz-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes yk-spinning{0%{-webkit-transform:rotate(0);-moz-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);-moz-transform:rotate(360deg);transform:rotate(360deg)}}`],
})
export class ProcessIconComponent implements OnInit, OnDestroy {

    private visible: boolean = true;
    private sub: Subscription;

    constructor( private service: ProcessService,
                 private options: ProcessOptions ) {
    }

    public ngOnInit() {
        this.sub = this.service.events.subscribe(
            ( event: ProcessEvent ) => {
                if (event.type === ProcessEventType.VISIBLE) {
                    this.visible = event.value;
                }
            }
        );
    }

    public ngOnDestroy(): void {
        if (this.sub) {
            this.sub.unsubscribe();
        }
    }

    public getProcessIconStyles(): any {
        return {
            'border-top-color': this.options.color,
            'border-left-color': this.options.color,
            'opacity': (this.visible && this.options.showSpinIcon) ? 1 : 0,
        };
    }

}
