/**
 * process-page.component
 */

import { Component, OnDestroy, OnInit } from '@angular/core';
import { ProcessEvent, ProcessEventType } from './process-event.class';
import { Subscription } from 'rxjs/Rx';
import { ProcessService } from './process.service';
import { animate, state, style, transition, trigger } from '@angular/animations';

@Component({
    selector: 'app-process-page',
    template: `<div class="yk-loading-page-container"><div *ngIf="visible" class="yk-loading-page-overlay left" [@flyInOut]="'down'"></div><div *ngIf="visible" class="yk-loading-page-overlay right" [@flyInOut]="'up'"></div><div *ngIf="visible" class="yk-loading-page-loader" [@flyInOut]="'show'"><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div><div class="yk-loading-page-line"></div></div></div>`,
    styles: [`*,::after,::before{-moz-box-sizing:border-box;box-sizing:border-box}.yk-loading-page-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;width:100vw;height:100vh}.yk-loading-page-overlay{position:fixed;top:0;height:100vh;display:inline-block;background-color:#000;z-index:999999;outline:transparent solid 1px}.yk-loading-page-overlay.left{width:76vw;left:-25vw;-webkit-transform:skew(-10deg) translateZ(0);-moz-transform:skew(-10deg) translateZ(0);transform:skew(-10deg) translateZ(0)}.yk-loading-page-overlay.right{right:-25vw;width:76vw;-webkit-transform:skew(-10deg) translateZ(0);-moz-transform:skew(-10deg) translateZ(0);transform:skew(-10deg) translateZ(0)}.yk-loading-page-loader{z-index:99999999}.yk-loading-page-line{-webkit-animation:expand 1s ease-in-out infinite;-moz-animation:expand 1s ease-in-out infinite;animation:expand 1s ease-in-out infinite;-moz-border-radius:10px;border-radius:10px;display:inline-block;-webkit-transform-origin:center center;-moz-transform-origin:center center;-ms-transform-origin:center center;transform-origin:center center;margin:0 6px;width:5px;height:60px}.yk-loading-page-line:nth-child(1){background:#db2828}.yk-loading-page-line:nth-child(2){-webkit-animation-delay:180ms;-moz-animation-delay:180ms;animation-delay:180ms;background:#f2711c}.yk-loading-page-line:nth-child(3){-webkit-animation-delay:360ms;-moz-animation-delay:360ms;animation-delay:360ms;background:#fbbd08}.yk-loading-page-line:nth-child(4){-webkit-animation-delay:540ms;-moz-animation-delay:540ms;animation-delay:540ms;background:#b5cc18}.yk-loading-page-line:nth-child(5){-webkit-animation-delay:720ms;-moz-animation-delay:720ms;animation-delay:720ms;background:#21ba45}.yk-loading-page-line:nth-child(6){-webkit-animation-delay:.9s;-moz-animation-delay:.9s;animation-delay:.9s;background:#00b5ad}.yk-loading-page-line:nth-child(7){-webkit-animation-delay:1.08s;-moz-animation-delay:1.08s;animation-delay:1.08s;background:#2185d0}.yk-loading-page-line:nth-child(8){-webkit-animation-delay:1.26s;-moz-animation-delay:1.26s;animation-delay:1.26s;background:#6435c9}.yk-loading-page-line:nth-child(9){-webkit-animation-delay:1.44s;-moz-animation-delay:1.44s;animation-delay:1.44s;background:#a333c8}@-webkit-keyframes expand{0%{-webkit-transform:scale(1);transform:scale(1)}25%{-webkit-transform:scale(2);transform:scale(2)}}@-moz-keyframes expand{0%{-moz-transform:scale(1);transform:scale(1)}25%{-moz-transform:scale(2);transform:scale(2)}}@keyframes expand{0%{-webkit-transform:scale(1);-moz-transform:scale(1);transform:scale(1)}25%{-webkit-transform:scale(2);-moz-transform:scale(2);transform:scale(2)}}`],
    animations: [
        trigger('flyInOut', [
            state('up', style({transform: 'translateY(0) skew(-10deg) translateZ(0)'})),
            state('down', style({transform: 'translateY(0) skew(-10deg) translateZ(0)'})),
            state('show', style({transform: 'opacity: 1'})),
            transition('void => up', [
                style({transform: 'translateY(150%) skew(-10deg) translateZ(0)'}),
                animate('650ms ease')
            ]),
            transition('up => void', [
                animate('650ms 200ms ease',
                    style({transform: 'translateY(150%) skew(-10deg) translateZ(0)'}))
            ]),
            transition('void => down', [
                style({transform: 'translateY(-150%) skew(-10deg) translateZ(0)'}),
                animate('650ms ease')
            ]),
            transition('down => void', [
                animate('650ms 200ms ease',
                    style({transform: 'translateY(-150%) skew(-10deg) translateZ(0)'}))
            ]),
            transition('void => show', [
                style({opacity: 0}),
                animate('200ms 500ms ease')
            ]),
            transition('show => void', [
                animate('200ms ease',
                    style({opacity: 0}))
            ]),
        ])
    ]
})
export class ProcessPageComponent implements OnInit, OnDestroy {

    public visible: boolean = true;
    private sub: Subscription;

    constructor( private service: ProcessService ) {
    }

    public ngOnInit() {
        this.sub = this.service.events.subscribe(
            ( event: ProcessEvent ) => {
                if (event.type === ProcessEventType.VISIBLE) {
                    this.visible = event.value;
                }
            }
        );
    }

    public ngOnDestroy(): void {
        if (this.sub) {
            this.sub.unsubscribe();
        }
    }
}
